@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkXMLPImageDataWriter extends vtkXMLPStructuredDataWriter
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -21,7 +21,7 @@ public class vtkXMLPImageDataWriter extends vtkXMLPStructuredDataWriter
 
     if (temp == 0) return null;
     return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native String GetDefaultFileExtension_3();
   public String GetDefaultFileExtension()
